\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{ecn}[2008/08/08 v1.0 libreslivres]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\ProcessOptions

\LoadClass{book}
\RequirePackage[T1]{fontenc}
\RequirePackage[latin1]{inputenc}
\RequirePackage[dvips]{graphicx}
\RequirePackage[dvips]{color}
\RequirePackage{fancyhdr}
\RequirePackage[small,hang]{caption2}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsfonts}
\RequirePackage{subfigure}
\RequirePackage{psfrag}
\RequirePackage{array}
\RequirePackage{lmodern}
\RequirePackage{eso-pic}
\RequirePackage[backref,colorlinks=true,dvips,urlcolor=gray,bookmarks=true,pagebackref,breaklinks=true]{hyperref}
\RequirePackage[frenchb]{babel}
\frenchbsetup{IndentFirst=false}
\addto\captionsfrench{\def\figurename{figure}}
\addto\captionsfrench{\def\tablename{tableau}}
\RequirePackage{pstricks,pst-all}
\RequirePackage{pstricks-add}

%paisseur des lignes:
\newlength{\epaisseur}
\setlength{\epaisseur}{.3mm}

% dfinition du d romain de drivation
\newcommand{\ud}{\mathrm{d}}

% dfinition des captions des objets flottants
\renewcommand{\captionfont}{\normalfont\it\selectfont}
\newcommand{\subcaptionfont}{\normalfont\selectfont}
\renewcommand{\captionlabelfont}{\bf \sffamily}
\renewcommand{\captionlabeldelim}{ -}
\newcommand{\chapternumfont}{\normalfont\fontsize{50}{30}\bfseries\selectfont}
\newcommand{\annexnumfont}{\normalfont\fontsize{50}{15}\bfseries\selectfont}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newdimen\betweenumberspace          % dimension for space between
\betweenumberspace=5\p@               % number and text of titles
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'entte des chapitres
\def\@makechapterhead#1{%
\vspace*{-20\p@}%
{\raggedright \normalfont\sffamily%
\ifnum \c@secnumdepth >\m@ne%
\if@mainmatter%
\centering
\rput[c](0,0){
\pscircle[fillstyle=solid,fillcolor=gray!20,linecolor=gray!20,framesep=125pt](0,0){6}%
\rput[c](0,-0.75){\scalebox{25}{\textcolor{white}{\thechapter}}}
\pstextpath[c]{\psarc[linestyle=none](0,0){5.5}{110}{70}}{\Huge\bfseries\sffamily #1}}
\par\nobreak%
\vspace*{140pt}%
\fi%
\fi%
\vspace*{100\p@}%
}%
}%

% dfinition de l'entte de la table des matires
\renewcommand{\tableofcontents}{
\pagestyle{empty}%
%\centering
\rput[c](6.5,2){
\pscircle[fillstyle=solid,fillcolor=gray!20,linecolor=gray!20,framesep=125pt](0,0){6}%
\pstextpath[c]{\psarc[linestyle=none](0,0){5.5}{110}{70}}{\Huge\bfseries\sffamily Table des matires}}
\par\nobreak%
\vspace*{5.5cm}%
%\bfseries\huge\sffamily Table des matires 
\markboth{\normalfont\normalsize\textit{\textcolor{bleu}{Table des matires}}}{}
\addcontentsline{toc}{chapter}{Table des matires}
\@starttoc{toc}}

% paramtres de la table des matires
\setcounter{tocdepth}{2}
\setcounter{secnumdepth}{2}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fancyhdr parameters
\newlength\debordementdroit\setlength\debordementdroit{0pt}
\newlength\debordementgauche\setlength\debordementgauche{30pt}
\pagestyle{fancy}
\fancyheadoffset{\debordementdroit}
\fancyfootoffset{\debordementdroit}
\renewcommand{\chaptermark}[1]{\markboth{\normalfont\normalsize\textit{\textcolor{bleu}{#1}}}{}}
\renewcommand{\sectionmark}[1]{\markright{\normalfont\normalsize\textit{\textcolor{bleu}{\thesection\hspace{2pt} #1}}}{}}
\fancyhf{} \fancyhead[LE,RO]{\normalfont\normalsize\textcolor{bleu}{\thepage}}
\fancyhead[LO]{\itshape{\rightmark}}
\fancyhead[RE]{\itshape{\leftmark}}
\renewcommand{\headrulewidth}{0.5pt}
\addtolength{\headheight}{0.5pt}
\renewcommand{\footrulewidth}{0pt}
\fancypagestyle{plain}{
\fancyhead{}
\renewcommand{\headrulewidth}{0pt}}
\renewcommand{\cleardoublepage}{%
\clearpage\ifodd\c@page\else
\hbox{}
\vspace*{\fill}
\thispagestyle{empty}% <--
\newpage
\fi} 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'apparence des sections et sous-sections
\renewcommand{\@seccntformat}[1]{\llap{\textcolor{bleu}{\csname the#1\endcsname}\hspace{0.5em}}}
                                      
\renewcommand{\section}{\@startsection{section}{1}{\z@}
                       {-4ex \@plus -1ex \@minus -.4ex}%
                       {1ex \@plus.2ex }%
                       {\normalfont\Large\sffamily\bfseries}}
\renewcommand{\subsection}{\@startsection {subsection}{2}{\z@}
                          {-3ex \@plus -0.1ex \@minus -.4ex}%
                          {0.5ex \@plus.2ex }%
                          {\normalfont\fontsize{12}{16}\sffamily\bfseries}}
\renewcommand{\subsubsection}{\@startsection {subsubsection}{3}{\z@}
                          {-2ex \@plus -0.1ex \@minus -.2ex}%
                          {0.2ex \@plus.2ex }%
                          {\normalfont\fontsize{11}{16}\sffamily\bfseries}}
                          
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                    {-2ex \@plus-.2ex \@minus .2ex}%
                                    {0.1ex}%
                                    {\normalfont\fontsize{11}{13}\sffamily\it}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\z@}%
                                       {-2ex \@plus-.1ex \@minus .2ex}%
                                       {0.1ex}%
                                      {\normalfont\normalsize\sffamily\bfseries}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition du comportement des guillemets
\catcode`\=\active \catcode`\=\active
\def{\og\ignorespaces}
\def{\fg}
